@@ -1,7 +1,7 @@
 from enum import Enum
 import random
-import ML
-# import RockPaperScissorsFullGame.ML as ML
+# import ML
+import RockPaperScissorsFullGame.ML as ML
 
 
 #Denotes instances of Item (plays) with values assigned to them.
