@@ -1,7 +1,7 @@
-# import RockPaperScissorsFullGame.RPS as RPS
-# import RockPaperScissorsFullGame.ML as ML
-import RPS
-import ML
+import RockPaperScissorsFullGame.RPS as RPS
+import RockPaperScissorsFullGame.ML as ML
+# import RPS
+# import ML
 
 def main():
     # arr = [{1 : {'player': 'Paper', 'computer': 'Rock'}}, {2 : {'player': 'Scissors', 'computer': 'Paper'}}, {3 : {'player': 'Rock', 'computer': 'Scissors'}}, {4 : {'player': 'Paper', 'computer': 'Paper'}}]
